==> haskell-tar-0.5.1.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tar.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tar
version: 0.5.1.0
id: tar-0.5.1.0-60eDJG9H72nHOuR0SQ7KSe
key: tar-0.5.1.0-60eDJG9H72nHOuR0SQ7KSe
license: BSD3
copyright: 2007 Bjorn Bringert <bjorn@bringert.net>
           2008-2016 Duncan Coutts <duncan@community.haskell.org>
maintainer: Duncan Coutts <duncan@community.haskell.org>
synopsis: Reading, writing and manipulating ".tar" archive files.
description:
    This library is for working with \"@.tar@\" archive files. It
    can read and write a range of common variations of archive
    format including V7, POSIX USTAR and GNU formats.
    .
    It provides support for packing and unpacking portable
    archives. This makes it suitable for distribution but not
    backup because details like file ownership and exact
    permissions are not preserved.
    .
    It also provides features for random access to archive
    content using an index.
category: Codec
author: Duncan Coutts <duncan@community.haskell.org>
        Bjorn Bringert <bjorn@bringert.net>
exposed: True
indefinite: False
exposed-modules:
    Codec.Archive.Tar Codec.Archive.Tar.Check Codec.Archive.Tar.Entry
    Codec.Archive.Tar.Index
hidden-modules: Codec.Archive.Tar.Types Codec.Archive.Tar.Read
                Codec.Archive.Tar.Write Codec.Archive.Tar.Pack
                Codec.Archive.Tar.Unpack Codec.Archive.Tar.Index.StringTable
                Codec.Archive.Tar.Index.IntTrie
abi: 4b14b9e4f668147d67d71a5805d1ddbc
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tar-0.5.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/tar-0.5.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tar-0.5.1.0
hs-libraries: HStar-0.5.1.0-60eDJG9H72nHOuR0SQ7KSe
depends:
    base-4.10.1.0 filepath-1.4.1.2 array-0.5.2.0 containers-0.5.10.2
    deepseq-1.4.3.0 directory-1.3.0.2 time-1.8.0.2 bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-tar/html/tar.haddock
haddock-html: /usr/share/doc/haskell-tar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tar-0.5.1.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tar.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tar
version: 0.5.1.0
id: tar-0.5.1.0-2NE6oowiyVxJcDjgLMgVCm
key: tar-0.5.1.0-2NE6oowiyVxJcDjgLMgVCm
license: BSD-3-Clause
copyright: 2007 Bjorn Bringert <bjorn@bringert.net>
           2008-2016 Duncan Coutts <duncan@community.haskell.org>
maintainer: Duncan Coutts <duncan@community.haskell.org>
author: Duncan Coutts <duncan@community.haskell.org>
        Bjorn Bringert <bjorn@bringert.net>
synopsis: Reading, writing and manipulating ".tar" archive files.
description:
    This library is for working with \"@.tar@\" archive files. It
    can read and write a range of common variations of archive
    format including V7, POSIX USTAR and GNU formats.
    .
    It provides support for packing and unpacking portable
    archives. This makes it suitable for distribution but not
    backup because details like file ownership and exact
    permissions are not preserved.
    .
    It also provides features for random access to archive
    content using an index.
category: Codec
abi: 88438dda91eb64a21d8d67f5ddd563b2
exposed: True
exposed-modules:
    Codec.Archive.Tar Codec.Archive.Tar.Check Codec.Archive.Tar.Entry
    Codec.Archive.Tar.Index
hidden-modules: Codec.Archive.Tar.Types Codec.Archive.Tar.Read
                Codec.Archive.Tar.Write Codec.Archive.Tar.Pack
                Codec.Archive.Tar.Unpack Codec.Archive.Tar.Index.StringTable
                Codec.Archive.Tar.Index.IntTrie
import-dirs: /usr/lib/ghc-8.4.3/site-local/tar-0.5.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/tar-0.5.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tar-0.5.1.0
hs-libraries: HStar-0.5.1.0-2NE6oowiyVxJcDjgLMgVCm
depends:
    base-4.11.1.0 filepath-1.4.2 array-0.5.2.0 containers-0.5.11.0
    deepseq-1.4.3.0 directory-1.3.1.5 time-1.8.0.2 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-tar/html/tar.haddock
haddock-html: /usr/share/doc/haskell-tar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
